@@ -28,9 +28,7 @@ SelectionTypeTreeWidget::SelectionTypeTreeWidget(bool backupData, QWidget *paren
     header()->hide();
 }
 
-SelectionTypeTreeWidget::~SelectionTypeTreeWidget()
-{
-}
+SelectionTypeTreeWidget::~SelectionTypeTreeWidget() = default;
 
 void SelectionTypeTreeWidget::initialize(bool backupData)
 {
@@ -122,9 +120,9 @@ bool SelectionTypeTreeWidget::removeNotSelectedItem(QTreeWidgetItem *parent)
     return hasChildren;
 }
 
-QHash<Utils::AppsType, Utils::importExportParameters> SelectionTypeTreeWidget::storedType() const
+QMap<Utils::AppsType, Utils::importExportParameters> SelectionTypeTreeWidget::storedType() const
 {
-    QHash<Utils::AppsType, Utils::importExportParameters> stored;
+    QMap<Utils::AppsType, Utils::importExportParameters> stored;
     Utils::importExportParameters var = typeChecked(mKmailItem);
     if (!var.isEmpty()) {
         stored.insert(Utils::KMail, var);
@@ -284,7 +282,7 @@ void SelectionTypeTreeWidget::loadFileName(const QString &fileName)
 {
     unSelectAllItems();
     TemplateSelection templateSelection;
-    const QHash<Utils::AppsType, Utils::importExportParameters> params = templateSelection.loadTemplate(fileName);
+    const QMap<Utils::AppsType, Utils::importExportParameters> params = templateSelection.loadTemplate(fileName);
     setParameters(params);
 }
 
@@ -320,8 +318,11 @@ QString SelectionTypeTreeWidget::exportedFileInfo()
     const QString templateStr = templateSelectionToString();
     QTemporaryFile tmp;
     tmp.open();
-    tmp.setAutoRemove(false);
-    PimCommon::Util::saveToFile(tmp.fileName(), templateStr);
+    if (!PimCommon::Util::saveToFile(tmp.fileName(), templateStr)) {
+        return {};
+    } else {
+        tmp.setAutoRemove(false);
+    }
     return tmp.fileName();
 }
 
@@ -336,10 +337,12 @@ QString SelectionTypeTreeWidget::templateSelectionToString()
 void SelectionTypeTreeWidget::saveAsDefaultTemplate()
 {
     const QString templateStr = templateSelectionToString();
-    QString ret = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/pimdataexporter/");
+    const QString ret = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/pimdataexporter/");
     QDir().mkpath(ret);
 
-    PimCommon::Util::saveToFile(ret + QStringLiteral("defaulttemplate.xml"), templateStr);
+    if (!PimCommon::Util::saveToFile(ret + QStringLiteral("defaulttemplate.xml"), templateStr)) {
+        qWarning() << "Impossible to save as defaulttemplate.xml";
+    }
 }
 
 void SelectionTypeTreeWidget::saveAsTemplate()
@@ -361,9 +364,9 @@ void SelectionTypeTreeWidget::initializeSubItem(QTreeWidgetItem *item, Utils::St
     }
 }
 
-void SelectionTypeTreeWidget::setParameters(const QHash<Utils::AppsType, Utils::importExportParameters> &params)
+void SelectionTypeTreeWidget::setParameters(const QMap<Utils::AppsType, Utils::importExportParameters> &params)
 {
-    QHash<Utils::AppsType, Utils::importExportParameters>::const_iterator i = params.constBegin();
+    QMap<Utils::AppsType, Utils::importExportParameters>::const_iterator i = params.constBegin();
     while (i != params.constEnd()) {
         switch (i.key()) {
         case Utils::KMail:
